summaryrefslogtreecommitdiffstats
path: root/kicker/menuext
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/menuext')
-rw-r--r--kicker/menuext/kate/katesessionmenu.cpp4
-rw-r--r--kicker/menuext/kate/katesessionmenu.h2
-rw-r--r--kicker/menuext/konsole/konsolebookmarkmenu.cpp4
-rw-r--r--kicker/menuext/prefmenu/prefmenu.cpp16
-rw-r--r--kicker/menuext/recentdocs/recentdocsmenu.cpp8
-rw-r--r--kicker/menuext/remote/remotemenu.cpp4
-rw-r--r--kicker/menuext/system/systemmenu.cpp2
-rw-r--r--kicker/menuext/tom/README2
-rw-r--r--kicker/menuext/tom/TASKGROUPS2
-rw-r--r--kicker/menuext/tom/tom.cc22
10 files changed, 33 insertions, 33 deletions
diff --git a/kicker/menuext/kate/katesessionmenu.cpp b/kicker/menuext/kate/katesessionmenu.cpp
index 634c63d3b..584a345aa 100644
--- a/kicker/menuext/kate/katesessionmenu.cpp
+++ b/kicker/menuext/kate/katesessionmenu.cpp
@@ -124,7 +124,7 @@ void KateSessionMenu::slotExec( int id )
"kate_session_button_create_anonymous" ) == KMessageBox::No )
return;
- if ( m_sessions.tqcontains( name ) &&
+ if ( m_sessions.contains( name ) &&
KMessageBox::warningYesNo( 0,
i18n("You allready have a session named %1. Do you want to open that session?").arg( name ),
i18n("Session exists") ) == KMessageBox::No )
@@ -147,4 +147,4 @@ void KateSessionMenu::slotExec( int id )
}
-// kate: space-indent: on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent: on; indent-width 2; replace-tabs on;
diff --git a/kicker/menuext/kate/katesessionmenu.h b/kicker/menuext/kate/katesessionmenu.h
index bee2ba32d..3d5519496 100644
--- a/kicker/menuext/kate/katesessionmenu.h
+++ b/kicker/menuext/kate/katesessionmenu.h
@@ -42,4 +42,4 @@ class KateSessionMenu : public KPanelMenu {
#endif // _KateSessionMenu_h_
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kicker/menuext/konsole/konsolebookmarkmenu.cpp b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
index 0a0f70feb..1a31fe55c 100644
--- a/kicker/menuext/konsole/konsolebookmarkmenu.cpp
+++ b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
@@ -105,14 +105,14 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
}
}
- KBookmarkGroup parentBookmark = m_pManager->tqfindByAddress( m_parentAddress ).toGroup();
+ KBookmarkGroup parentBookmark = m_pManager->findByAddress( m_parentAddress ).toGroup();
Q_ASSERT(!parentBookmark.isNull());
bool separatorInserted = false;
for ( KBookmark bm = parentBookmark.first(); !bm.isNull();
bm = parentBookmark.next(bm) )
{
TQString text = bm.text();
- text.tqreplace( '&', "&&" );
+ text.replace( '&', "&&" );
if ( !separatorInserted && m_bIsRoot) { // inserted before the first konq bookmark, to avoid the separator if no konq bookmark
m_parentMenu->insertSeparator();
separatorInserted = true;
diff --git a/kicker/menuext/recentdocs/recentdocsmenu.cpp b/kicker/menuext/recentdocs/recentdocsmenu.cpp
index bbff5a3f2..b8c3c6d81 100644
--- a/kicker/menuext/recentdocs/recentdocsmenu.cpp
+++ b/kicker/menuext/recentdocs/recentdocsmenu.cpp
@@ -72,17 +72,17 @@ void RecentDocsMenu::initialize() {
// Make sure this entry is not already present in the menu
alreadyPresentInMenu = 0;
for ( TQStringList::Iterator previt = previousEntries.begin(); previt != previousEntries.end(); ++previt ) {
- if (TQString::localeAwareCompare(*previt, f.readName().tqreplace('&', TQString::fromAscii("&&") )) == 0) {
+ if (TQString::localeAwareCompare(*previt, f.readName().replace('&', TQString::fromAscii("&&") )) == 0) {
alreadyPresentInMenu = 1;
}
}
if (alreadyPresentInMenu == 0) {
// Add item to menu
- insertItem(SmallIconSet(f.readIcon()), f.readName().tqreplace('&', TQString::fromAscii("&&") ), id++);
+ insertItem(SmallIconSet(f.readIcon()), f.readName().replace('&', TQString::fromAscii("&&") ), id++);
// Append to duplicate checking list
- previousEntries.append(f.readName().tqreplace('&', TQString::fromAscii("&&") ));
+ previousEntries.append(f.readName().replace('&', TQString::fromAscii("&&") ));
}
}
@@ -114,7 +114,7 @@ void RecentDocsMenu::mouseMoveEvent(TQMouseEvent* e) {
if (!(e->state() & LeftButton))
return;
- if (!rect().tqcontains(_mouseDown))
+ if (!rect().contains(_mouseDown))
return;
int dragLength = (e->pos() - _mouseDown).manhattanLength();
diff --git a/kicker/menuext/remote/remotemenu.cpp b/kicker/menuext/remote/remotemenu.cpp
index 3547e3f9b..c09f9a825 100644
--- a/kicker/menuext/remote/remotemenu.cpp
+++ b/kicker/menuext/remote/remotemenu.cpp
@@ -93,7 +93,7 @@ void RemoteMenu::initialize()
for(; name!=endf; ++name)
{
- if (!names_found.tqcontains(*name))
+ if (!names_found.contains(*name))
{
names_found.append(*name);
TQString filename = *dirpath+*name;
@@ -124,7 +124,7 @@ void RemoteMenu::openRemoteDir()
void RemoteMenu::slotExec(int id)
{
- if (m_desktopMap.tqcontains(id))
+ if (m_desktopMap.contains(id))
{
new KRun(m_desktopMap[id]);
}
diff --git a/kicker/menuext/system/systemmenu.cpp b/kicker/menuext/system/systemmenu.cpp
index 33eba2558..12ec087d8 100644
--- a/kicker/menuext/system/systemmenu.cpp
+++ b/kicker/menuext/system/systemmenu.cpp
@@ -77,7 +77,7 @@ void SystemMenu::initialize()
void SystemMenu::slotExec(int id)
{
- if(!m_urlMap.tqcontains(id)) return;
+ if(!m_urlMap.contains(id)) return;
new KRun(m_urlMap[id]); // will delete itself
}
diff --git a/kicker/menuext/tom/README b/kicker/menuext/tom/README
index 8cc07d507..2616c76c5 100644
--- a/kicker/menuext/tom/README
+++ b/kicker/menuext/tom/README
@@ -58,7 +58,7 @@ What should be the default task entry format be:
a) Task Name
b) Task Name (App Name)
c) App Name (Task Name) <-- silly option =)
-Should "Run A Command..." be tqreplaced by an inline combobox?
+Should "Run A Command..." be replaced by an inline combobox?
Pros: It's more obvious and will work even if kdesktop is gone. The widget
is already written (in tom.cc)
Cons: It makes it stand out too much over other entries, takes up more room
diff --git a/kicker/menuext/tom/TASKGROUPS b/kicker/menuext/tom/TASKGROUPS
index 1cb8a41b9..c1aa1ed98 100644
--- a/kicker/menuext/tom/TASKGROUPS
+++ b/kicker/menuext/tom/TASKGROUPS
@@ -7,7 +7,7 @@ of tasks in the group (NumTasks) and optionally whether or not it is hidden
(Hidden).
For each task there is a numbered section in the file in the form TaskN. Each
-section tqcontains the user visible name for the task (Name), the associated
+section contains the user visible name for the task (Name), the associated
.desktop file and optionally whether or not it is hidden (Hidden).
An example file can be found below.
diff --git a/kicker/menuext/prefmenu/prefmenu.cpp b/kicker/menuext/prefmenu/prefmenu.cpp
index fc32de55d..0c072e026 100644
--- a/kicker/menuext/prefmenu/prefmenu.cpp
+++ b/kicker/menuext/prefmenu/prefmenu.cpp
@@ -84,7 +84,7 @@ void PrefMenu::insertMenuItem(KService::Ptr& s,
if (KickerSettings::menuEntryFormat() == KickerSettings::NameAndDescription)
{
if (!suppressGenericNames ||
- !suppressGenericNames->tqcontains(s->untranslatedGenericName()))
+ !suppressGenericNames->contains(s->untranslatedGenericName()))
{
serviceName = TQString("%1 (%2)").arg(serviceName).arg(comment);
}
@@ -119,8 +119,8 @@ void PrefMenu::insertMenuItem(KService::Ptr& s,
}
// item names may contain ampersands. To avoid them being converted
- // to accelerators, tqreplace them with two ampersands.
- serviceName.tqreplace("&", "&&");
+ // to accelerators, replace them with two ampersands.
+ serviceName.replace("&", "&&");
int newId = insertItem(KickerLib::menuIconSet(s->icon()), serviceName, nId, nIndex);
m_entryMap.insert(newId, static_cast<KSycocaEntry*>(s));
@@ -155,7 +155,7 @@ void PrefMenu::mouseMoveEvent(TQMouseEvent * ev)
return;
}
- if (!m_entryMap.tqcontains(id))
+ if (!m_entryMap.contains(id))
{
kdDebug(1210) << "Cannot find service with menu id " << id << endl;
return;
@@ -224,7 +224,7 @@ void PrefMenu::dragEnterEvent(TQDragEnterEvent *event)
void PrefMenu::dragLeaveEvent(TQDragLeaveEvent */*event*/)
{
// see PrefMenu::dragEnterEvent why this is nescessary
- if (!frameGeometry().tqcontains(TQCursor::pos()))
+ if (!frameGeometry().contains(TQCursor::pos()))
{
KURLDrag::setTarget(0);
}
@@ -296,8 +296,8 @@ void PrefMenu::initialize()
}
// Item names may contain ampersands. To avoid them being converted
- // to accelerators, tqreplace each ampersand with two ampersands.
- groupCaption.tqreplace("&", "&&");
+ // to accelerators, replace each ampersand with two ampersands.
+ groupCaption.replace("&", "&&");
PrefMenu* m = new PrefMenu(g->name(), g->relPath(), this);
m->setCaption(groupCaption);
@@ -323,7 +323,7 @@ void PrefMenu::initialize()
void PrefMenu::slotExec(int id)
{
- if (!m_entryMap.tqcontains(id))
+ if (!m_entryMap.contains(id))
{
return;
}
diff --git a/kicker/menuext/tom/tom.cc b/kicker/menuext/tom/tom.cc
index 7ec080a8b..3a4ebf4ed 100644
--- a/kicker/menuext/tom/tom.cc
+++ b/kicker/menuext/tom/tom.cc
@@ -109,7 +109,7 @@ class runMenuWidget : public TQWidget, public QMenuItem
l2->setBuddy(this);
runLayout->addWidget(l2);*/
m_runEdit = new KHistoryCombo(this);
- m_runEdit->tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred);
+ m_runEdit->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred);
runLayout->addWidget(m_runEdit, 10);
runLayout->addSpacing(KDialog::spacingHint());
@@ -143,7 +143,7 @@ class runMenuWidget : public TQWidget, public QMenuItem
TQPainter p(this);
TQRect r(rect());
// ew, nasty hack. may result in coredumps due to horrid C-style cast???
- kapp->style().tqdrawControl(TQStyle::CE_PopupMenuItem, &p, m_menu, r, palette().active(), TQStyle::Style_Enabled,
+ kapp->style().drawControl(TQStyle::CE_PopupMenuItem, &p, m_menu, r, palette().active(), TQStyle::Style_Enabled,
TQStyleOption(static_cast<TQMenuItem*>(this), 0, KIcon::SizeMedium ));
p.drawPixmap(KDialog::spacingHint(), 1, icon);
p.drawText((KDialog::spacingHint() * 2) + KIcon::SizeMedium, textRect.height() + ((height() - textRect.height()) / 2), i18n("Run:"));
@@ -239,7 +239,7 @@ void TOM::initializeRecentDocs()
KDesktopFile f(*it, true /* read only */);
m_recentDocsMenu->insertItem(DesktopIcon(f.readIcon(), KIcon::SizeMedium),
- f.readName().tqreplace('&', "&&"), id);
+ f.readName().replace('&', "&&"), id);
++id;
}
}
@@ -301,8 +301,8 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
}
TQString name = config.readEntry("Name");
- // in case the name tqcontains an ampersand, double 'em up
- name.tqreplace("&", "&&");
+ // in case the name contains an ampersand, double 'em up
+ name.replace("&", "&&");
TQString desktopfile = config.readPathEntry("DesktopFile");
KService::Ptr pService = KService::serviceByDesktopPath(desktopfile);
@@ -655,7 +655,7 @@ bool TOM::loadSidePixmap()
// limit max/min brightness
int r, g, b;
color.rgb(&r, &g, &b);
- int gray = tqGray(r, g, b);
+ int gray = qGray(r, g, b);
if (gray > 180) {
r = (r - (gray - 180) < 0 ? 0 : r - (gray - 180));
g = (g - (gray - 180) < 0 ? 0 : g - (gray - 180));
@@ -736,13 +736,13 @@ void TOM::setMaximumSize(int w, int h)
TQRect TOM::sideImageRect()
{
- return TQStyle::tqvisualRect( TQRect( frameWidth(), frameWidth(), m_sidePixmap.width(),
+ return TQStyle::visualRect( TQRect( frameWidth(), frameWidth(), m_sidePixmap.width(),
height() - 2*frameWidth() ), this );
}
void TOM::resizeEvent(TQResizeEvent * e)
{
- setFrameRect( TQStyle::tqvisualRect( TQRect( m_sidePixmap.width(), 0,
+ setFrameRect( TQStyle::visualRect( TQRect( m_sidePixmap.width(), 0,
width() - m_sidePixmap.width(), height() ), this ) );
}
@@ -757,7 +757,7 @@ void TOM::paintEvent(TQPaintEvent * e)
style().drawPrimitive( TQStyle::PE_PanelPopup, &p,
TQRect( 0, 0, width(), height() ),
- tqcolorGroup(), TQStyle::Style_Default,
+ colorGroup(), TQStyle::Style_Default,
TQStyleOption( frameWidth(), 0 ) );
TQRect r = sideImageRect();
@@ -775,7 +775,7 @@ TQMouseEvent TOM::translateMouseEvent( TQMouseEvent* e )
{
TQRect side = sideImageRect();
- if ( !side.tqcontains( e->pos() ) )
+ if ( !side.contains( e->pos() ) )
return *e;
TQPoint newpos( e->pos() );
@@ -824,7 +824,7 @@ void TOM::runCommand()
void TOM::runTask(int id)
{
- if (!m_tasks.tqcontains(id)) return;
+ if (!m_tasks.contains(id)) return;
kapp->propagateSessionManager();
KApplication::startServiceByDesktopPath(m_tasks[id]->desktopEntryPath(),